==> apache-camel-4.11.0-src.zip: apache-camel-4.11.0/core/camel-core-processor/src/main/java/org/apache/camel/processor/TokenizerProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.processor;

import java.util.ArrayList;
import java.util.List;

import org.apache.camel.AsyncCallback;
import org.apache.camel.AsyncProcessor;
import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.Exchange;
import org.apache.camel.Navigate;
import org.apache.camel.Processor;
import org.apache.camel.spi.IdAware;
import org.apache.camel.spi.RouteIdAware;
import org.apache.camel.spi.Tokenizer;
import org.apache.camel.support.AsyncProcessorConverterHelper;
import org.apache.camel.support.AsyncProcessorSupport;

/**
 * This implements the core processor for handling tokenization
 */
public class TokenizerProcessor extends AsyncProcessorSupport
        implements Navigate<Processor>,
        CamelContextAware, IdAware, RouteIdAware {

    private final AsyncProcessor processor;
    private final Tokenizer tokenizer;

    private CamelContext camelContext;
    private String id;
    private String routeId;

    public TokenizerProcessor(Processor processor, Tokenizer tokenizer) {
        this.processor = AsyncProcessorConverterHelper.convert(processor);
        this.tokenizer = tokenizer;
    }

    @Override
    public boolean process(Exchange exchange, AsyncCallback callback) {
        final String[] tokenized = tokenizer.tokenize(exchange);

        exchange.getMessage().setBody(tokenized);
        return processor.process(exchange, callback);

    }

    @Override
    public List<Processor> next() {
        if (!hasNext()) {
            return null;
        }
        List<Processor> answer = new ArrayList<>(1);
        answer.add(processor);
        return answer;
    }

    @Override
    public boolean hasNext() {
        return false;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }

    @Override
    public String getId() {
        return id;
    }

    @Override
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public String getRouteId() {
        return routeId;
    }

    @Override
    public void setRouteId(String routeId) {
        this.routeId = routeId;
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/core/camel-core-processor/src/main/java/org/apache/camel/processor/TokenizerProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.processor;

import java.util.ArrayList;
import java.util.List;

import org.apache.camel.AsyncCallback;
import org.apache.camel.AsyncProcessor;
import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.Exchange;
import org.apache.camel.Navigate;
import org.apache.camel.Processor;
import org.apache.camel.spi.IdAware;
import org.apache.camel.spi.RouteIdAware;
import org.apache.camel.spi.Tokenizer;
import org.apache.camel.support.AsyncProcessorConverterHelper;

/**
 * This implements the core processor for handling tokenization
 */
public class TokenizerProcessor extends BaseProcessorSupport
        implements Navigate<Processor>, CamelContextAware, IdAware, RouteIdAware {

    private final AsyncProcessor processor;
    private final Tokenizer tokenizer;
    private CamelContext camelContext;
    private String id;
    private String routeId;

    public TokenizerProcessor(Processor processor, Tokenizer tokenizer) {
        this.processor = AsyncProcessorConverterHelper.convert(processor);
        this.tokenizer = tokenizer;
    }

    @Override
    public boolean process(Exchange exchange, AsyncCallback callback) {
        final String[] tokenized = tokenizer.tokenize(exchange);

        exchange.getMessage().setBody(tokenized);
        return processor.process(exchange, callback);

    }

    @Override
    public List<Processor> next() {
        if (!hasNext()) {
            return null;
        }
        List<Processor> answer = new ArrayList<>(1);
        answer.add(processor);
        return answer;
    }

    @Override
    public boolean hasNext() {
        return false;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }

    @Override
    public String getId() {
        return id;
    }

    @Override
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public String getRouteId() {
        return routeId;
    }

    @Override
    public void setRouteId(String routeId) {
        this.routeId = routeId;
    }
}
